package com.xinelu.manage.mapper.basedietinfo;

import com.xinelu.manage.domain.basedietinfo.BaseDietInfo;

import java.util.List;

/**
 * 饮食知识库Mapper接口
 *
 * @author xinelu
 * @date 2024-05-17
 */
public interface BaseDietInfoMapper {
    /**
     * 查询饮食知识库
     *
     * @param id 饮食知识库主键
     * @return 饮食知识库
     */
    BaseDietInfo selectBaseDietInfoById(Long id);

    /**
     * 查询饮食知识库列表
     *
     * @param baseDietInfo 饮食知识库
     * @return 饮食知识库集合
     */
    List<BaseDietInfo> selectBaseDietInfoList(BaseDietInfo baseDietInfo);

    /**
     * 新增饮食知识库
     *
     * @param baseDietInfo 饮食知识库
     * @return 结果
     */
    int insertBaseDietInfo(BaseDietInfo baseDietInfo);

    /**
     * 修改饮食知识库
     *
     * @param baseDietInfo 饮食知识库
     * @return 结果
     */
    int updateBaseDietInfo(BaseDietInfo baseDietInfo);

    /**
     * 删除饮食知识库
     *
     * @param id 饮食知识库主键
     * @return 结果
     */
    int deleteBaseDietInfoById(Long id);

    /**
     * 批量删除饮食知识库
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteBaseDietInfoByIds(Long[] ids);
}
